@@ -1,13 +1,15 @@
 // doesn't work at all in wasm, so let's just not bother..
 #![cfg(not(target_arch = "wasm32"))]
+// Clippy TODO
+#![allow(clippy::all)]
 
 mod malloc_buf;
 
-pub use encode::{Encode, EncodeArguments, Encoding};
-pub use message::{Message, MessageArguments, MessageError};
+pub use crate::encode::{Encode, EncodeArguments, Encoding};
+pub use crate::message::{Message, MessageArguments, MessageError};
 
-pub use message::send_message as __send_message;
-pub use message::send_super_message as __send_super_message;
+pub use crate::message::send_message as __send_message;
+pub use crate::message::send_super_message as __send_super_message;
 
 #[macro_use]
 mod macros;
