@@ -1,12 +1,12 @@
-use malloc_buf::MallocBuffer;
+use crate::malloc_buf::MallocBuffer;
 use std::ffi::{CStr, CString};
 use std::fmt;
 use std::os::raw::{c_char, c_int, c_uint, c_void};
 use std::ptr;
 use std::str;
 
-use encode;
-use {Encode, Encoding};
+use crate::encode;
+use crate::{Encode, Encoding};
 
 #[cfg(not(target_arch = "aarch64"))]
 pub type BOOL = ::std::os::raw::c_schar;
@@ -448,6 +448,7 @@ impl Object {
 
     /// Returns a reference to the ivar of self with the given name.
     /// Panics if self has no ivar with the given name.
+    /// # Safety
     /// Unsafe because the caller must ensure that the ivar is actually
     /// of type `T`.
     pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
@@ -473,6 +474,7 @@ impl Object {
 
     /// Returns a mutable reference to the ivar of self with the given name.
     /// Panics if self has no ivar with the given name.
+    /// # Safety
     /// Unsafe because the caller must ensure that the ivar is actually
     /// of type `T`.
     pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
@@ -498,6 +500,7 @@ impl Object {
 
     /// Sets the value of the ivar of self with the given name.
     /// Panics if self has no ivar with the given name.
+    /// # Safety
     /// Unsafe because the caller must ensure that the ivar is actually
     /// of type `T`.
     pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)
@@ -517,8 +520,8 @@ impl fmt::Debug for Object {
 #[cfg(test)]
 mod tests {
     use super::{Class, Protocol, Sel};
-    use test_utils;
-    use Encode;
+    use crate::test_utils;
+    use crate::Encode;
 
     #[test]
     fn test_ivar() {
